==> tdesdk-R14.0.0-x86_64-ifx.txz: install/doinst.sh <==
( cd usr/share/doc/tde/HTML/en/cervisia ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/cervisia ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbabel ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbabel ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbugbuster ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbugbuster ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kompare ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kompare ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdesvn-build ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdesvn-build ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdecachegrind ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdecachegrind ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/umbrello ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/umbrello ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/lib64 ; rm -rf libcvsservice.so.0 )
( cd usr/lib64 ; ln -sf libcvsservice.so.0.1.0 libcvsservice.so.0 )
( cd usr/lib64 ; rm -rf libcvsservice.so )
( cd usr/lib64 ; ln -sf libcvsservice.so.0 libcvsservice.so )
( cd usr/lib64 ; rm -rf libkbabelcommon.so.3 )
( cd usr/lib64 ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so.3 )
( cd usr/lib64 ; rm -rf libkbabelcommon.so )
( cd usr/lib64 ; ln -sf libkbabelcommon.so.3 libkbabelcommon.so )
( cd usr/lib64 ; rm -rf libkbabeldictplugin.so.1 )
( cd usr/lib64 ; ln -sf libkbabeldictplugin.so.1.2.0 libkbabeldictplugin.so.1 )
( cd usr/lib64 ; rm -rf libkbabeldictplugin.so )
( cd usr/lib64 ; ln -sf libkbabeldictplugin.so.1 libkbabeldictplugin.so )
( cd usr/lib64 ; rm -rf libkspy.so.1 )
( cd usr/lib64 ; ln -sf libkspy.so.1.2.0 libkspy.so.1 )
( cd usr/lib64 ; rm -rf libkspy.so )
( cd usr/lib64 ; ln -sf libkspy.so.1 libkspy.so )
( cd usr/lib64 ; rm -rf libkstartperf.so.1 )
( cd usr/lib64 ; ln -sf libkstartperf.so.1.0.0 libkstartperf.so.1 )
( cd usr/lib64 ; rm -rf libkstartperf.so )
( cd usr/lib64 ; ln -sf libkstartperf.so.1 libkstartperf.so )

==> tdesdk-14.0.11-x86_64-ifx.txz: install/doinst.sh <==

# Update the desktop database:
/usr/bin/update-desktop-database ./usr/share/applications

# Update hicolor theme cache:
/usr/bin/gtk-update-icon-cache -f -t ./usr/share/icons/hicolor

# Update the mime database:
/usr/bin/update-mime-database -Vn usr/share/mime

( cd usr/lib64 ; rm -rf libcvsservice.so )
( cd usr/lib64 ; ln -sf libcvsservice.so.0 libcvsservice.so )
( cd usr/lib64 ; rm -rf libcvsservice.so.0 )
( cd usr/lib64 ; ln -sf libcvsservice.so.0.0.1 libcvsservice.so.0 )
( cd usr/lib64 ; rm -rf libkbabelcommon.so )
( cd usr/lib64 ; ln -sf libkbabelcommon.so.3 libkbabelcommon.so )
( cd usr/lib64 ; rm -rf libkbabelcommon.so.3 )
( cd usr/lib64 ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so.3 )
( cd usr/lib64 ; rm -rf libkbabeldictplugin.so )
( cd usr/lib64 ; ln -sf libkbabeldictplugin.so.1 libkbabeldictplugin.so )
( cd usr/lib64 ; rm -rf libkbabeldictplugin.so.1 )
( cd usr/lib64 ; ln -sf libkbabeldictplugin.so.1.2.0 libkbabeldictplugin.so.1 )
( cd usr/lib64 ; rm -rf libkompareinterface.so )
( cd usr/lib64 ; ln -sf libkompareinterface.so.0 libkompareinterface.so )
( cd usr/lib64 ; rm -rf libkompareinterface.so.0 )
( cd usr/lib64 ; ln -sf libkompareinterface.so.0.0.0 libkompareinterface.so.0 )
( cd usr/lib64 ; rm -rf libkspy.so )
( cd usr/lib64 ; ln -sf libkspy.so.1 libkspy.so )
( cd usr/lib64 ; rm -rf libkspy.so.1 )
( cd usr/lib64 ; ln -sf libkspy.so.1.2.0 libkspy.so.1 )
( cd usr/lib64 ; rm -rf libkstartperf.so )
( cd usr/lib64 ; ln -sf libkstartperf.so.1 libkstartperf.so )
( cd usr/lib64 ; rm -rf libkstartperf.so.1 )
( cd usr/lib64 ; ln -sf libkstartperf.so.1.0.0 libkstartperf.so.1 )
( cd usr/lib64 ; rm -rf libtdeunittestgui.so )
( cd usr/lib64 ; ln -sf libtdeunittestgui.so.0 libtdeunittestgui.so )
( cd usr/lib64 ; rm -rf libtdeunittestgui.so.0 )
( cd usr/lib64 ; ln -sf libtdeunittestgui.so.0.0.0 libtdeunittestgui.so.0 )
( cd usr/share/doc/tde/HTML/en/cervisia ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/cervisia ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbabel ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbabel ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kbugbuster ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kbugbuster ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kompare ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kompare ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/kuiviewer ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/kuiviewer ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdecachegrind ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdecachegrind ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/tdesvn-build ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/tdesvn-build ; ln -sf /usr/share/doc/tde/HTML/en/common common )
( cd usr/share/doc/tde/HTML/en/umbrello ; rm -rf common )
( cd usr/share/doc/tde/HTML/en/umbrello ; ln -sf /usr/share/doc/tde/HTML/en/common common )
